#
# spec file for package ART
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ART
Version:        1.17.2
Release:        bp155.1.6
Summary:        Rawtherapee fork with masks and simplified UI
License:        GPL-3.0-only
URL:            https://bitbucket.org/agriggio/art/wiki/Home
Source:         https://bitbucket.org/agriggio/art/downloads/%{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glibmm2-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libraw-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(exiv2)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(fftw3f)
BuildRequires:  pkgconfig(fftw3l)
BuildRequires:  pkgconfig(gail-3.0)
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(gdk-broadway-3.0)
BuildRequires:  pkgconfig(gdk-wayland-3.0)
BuildRequires:  pkgconfig(gdk-x11-3.0)
BuildRequires:  pkgconfig(gdkmm-3.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gmodule-export-2.0)
BuildRequires:  pkgconfig(gmodule-no-export-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk+-broadway-3.0)
BuildRequires:  pkgconfig(gtk+-unix-print-3.0)
BuildRequires:  pkgconfig(gtk+-wayland-3.0)
BuildRequires:  pkgconfig(gtk+-x11-3.0)
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(lensfun)
BuildRequires:  pkgconfig(libcanberra-gtk3)
BuildRequires:  pkgconfig(libiptcdata)
BuildRequires:  pkgconfig(libprofiler)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libtcmalloc)
BuildRequires:  pkgconfig(libtcmalloc_debug)
BuildRequires:  pkgconfig(libtcmalloc_minimal)
BuildRequires:  pkgconfig(libtcmalloc_minimal_debug)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(zlib)

%description
A free, open-source, cross-platform raw image processing program. ART is a derivative of the popular RawTherapee, trading a bit of customization and control over various processing parameters for a simpler and (hopefully) easier to use interface, while still maintaining the power and quality of RawTherapee.

%prep
%autosetup -p1

%build
# Upstream recommended '-O3' optimisation, do not change
export CFLAGS="%(echo %{optflags} | sed 's/-O2/-O3/' | sed 's/-D_FORTIFY_SOURCE=2/-D_FORTIFY_SOURCE=3/')"
export CXXFLAGS="$CFLAGS"

%cmake \
    -DCMAKE_SHARED_LINKER_FLAGS="-Wl,--as-needed -Wl,-z,now" \
    -DCMAKE_CXX_FLAGS="$CXXFLAGS" \
    -DCMAKE_C_FLAGS="$CFLAGS" \
    -DCACHE_NAME_SUFFIX="" \
    -DENABLE_LIBRAW="ON"
%cmake_build

%install
%cmake_install
desktop-file-install --dir %{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/%{name}.desktop
mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}%{_datadir}/doc/%{name} %{buildroot}%{_docdir}/%{name}

%fdupes %{buildroot}/%{_prefix}

%files
%{_bindir}/*
%{_libdir}/librtengine.so
%{_datadir}/%{name}/
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/applications/%{name}.desktop
%{_mandir}/*/%{name}*
%{_docdir}/%{name}

%changelog
* Wed Dec  7 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.17.2:
  * fixed bad interaction between film negative and dehaze or dynamic range compression
  * fixed regression in loading pixel-shift raw files
  * draw the crop guides in the batch queue thumbnails
  * spot removal: fixed history messages
  * PDAF lines filter: fixed oob accesses
  * added script to import wb presets from darktable
  * added DCP profiles from RT
  * film negative: show deprecation warning for "color space"
  * grain: removed redundant "scale" parameter
  * metadata: write star rating to the output image
  * highlight recovery: fixed crash due to typo
  * camconst: added raw_crop for Fuji X-H2
  * support camconst raw_crop when using the libraw decoder
  * dcraw: reject RGBA tiff files
  * replaced "balanced" highlight recovery with "inpaint opposed" from darktable
* Wed Nov  2 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.16.4:
  * crop window: reset the tool to "hand" after a "spot wb" action
  * allow to save pngs uncompressed
  * improved support for custom loaders and savers
  * metadata: trying to improve lens identification for canon cameras
  * reverted thumbnail.cc change due to glitch in the file browser (issue #267)
  * trying to improve the (perceived) responsiveness of the file browser
* Fri Oct  7 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.16.3:
  * editorpanel: fixed refresh of image area when switching images
  * clutstore: do not search for working profile in the file name for CLF LUTs
  * pipeline: move film simulation earlier (right after tone curve)
  * tone equalizer: improved robustness of regularization with hdr images
  * avoid infinities when loading and manipulating hdr images
  * exposure: do not use a LUT, it's not needed
  * fixed bug in applying partial profiles in append mode from the combobox
  * filecatalog: let the user choose which sidecars to affect when deleting a file
  * colorcorrection: slightly extend the range of offset sliders
  * tonecurve: fixed glitch in expansion of curve according to the white point
  * denoise: testing new ways of adjusting parameters according to the scale factor
* Tue Sep  6 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.16.2:
  * Fixed bug in fast-path for output profile application.
  * Fixed segfault when the thumb cache contains an invalid date.
  * Update camera matrices.
  * Update translations.
  * LUT: protect against NaN indices.
  * Img out: added custom ICC profile conversion to avoid clamping to [0,1].
  * Color correction: added LUT mode.
  * Handle linear DNG as other raw images.
  * Tonecurve: improved range for the saturation2 curve.
  * Denoise: some tweaks to the detail mask.
  * Filmsimulation: added support for ACES clf LMT LUTs using OpenColorIOv2.
  * Logenc: added highlight precompression.
  * Tonecurve: allow whitepoint to go up to 100 (~10000 nits).
- Drop fix-ppc-cflags.patch
* Thu Aug 18 2022 Paolo Stivanin <info@paolostivanin.com>
- Disable LTO, since it makes the program crashing.
* Wed Aug 17 2022 Paolo Stivanin <info@paolostivanin.com>
- Add fix-ppc-cflags.patch: set mcpu=native instead of march=native
  on ppc64, otherwise compilation will fail.
* Mon Jul 25 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.15:
  * Many changes, see
    https://bitbucket.org/agriggio/art/branches/compare/1.15%%0D1.14
- Use released tarballs instead of git service for source.
- Drop add_releaseinfo.patch: No longer needed when using released
  source tarballs.
- Drop duplicated options passed to cmake.
- Drop post(un) scriptlets running update-desktop-database and
  gtk-update-icon-cache: these are taken care of by file triggers.
* Wed Jun 29 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.14 (no changelog)
* Tue Apr 19 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.13 (no changelog)
* Fri Feb 18 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.12.1 (no changelog)
* Fri Dec 31 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.12 (no changelog)
* Wed Dec 15 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.11.1 (no changelog)
* Mon Nov  8 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.10.1 (no changelog)
* Mon Jul 19 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.9.3 (no changelog)
* Fri May 28 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.9.1:
  * New gradient mask
  * Updated the CR3 decoder to the latest from libraw
  * Added option to periodically auto-save arp sidecars
  * Slightly reworked the UI of the Log Tone Mapping tool
  * A bunch of bug fixes
* Fri Apr  2 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.8.3 (no changelog)
* Tue Feb 23 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.8.2 (no changelog)
* Thu Feb 18 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.8.1 (no changelog)
* Fri Feb  5 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.8:
  * slightly improved “colour propagation” highlight recovery
    (trying to mitigate artifacts that might sometimes occur)
  * added Spanish and Catalan translations
  * changed the UI of the color/tone correction tool in “HSL factors” mode,
    from sliders to color wheels
  * added “luminance mode” for color correction with “separate RGB channels”
  * improved RCD demosaicing code, taken from RT
  * added a new “Glow” mode to the smoothing filter, inspired by recent discussions here
  * simplified and improved the “final smoothing” part of the “noise reduction” tool
    (median is gone, replaced by a custom-tweaked non-local means implementation)
  * you can now select whether you want to use “hovering navigation” in the inspector
  * the brush mask now includes a “live preview” of the brush strokes
* Mon Jan  4 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.7.1:
  * improved usability of the brush mask, now strokes are smoother
    (you can go faster and still get a continuous stroke) and if you
    have a drawing tablet the brush radius and/or its hardness
    can be made pressure-sensitive
  * added support for lens correction parameters embedded
    in EXIF metadata
  * improved batch renaming, now supporting also moving to
    different directories
  * added support for Fuji GFX 100 pixel-shift files
    (both 4- and 16-frame), in combination with the make_arq 2 tool.
  * added support for using the “fast float” plugin of LCMS2
    for (significantly) faster color space conversions
  * various bug fixes
* Tue Dec  1 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.6.1 (no changelog)
* Tue Nov 24 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.6 (no changelog)
* Fri Oct 23 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.5.4 (no changelog)
* Thu Sep 17 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.5.3 (no changelog)
* Wed Sep  2 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.5.0:
  * added support for camera-specific white balance presets
  * added support for manipulating WB by setting the R,G,B multipliers
  * added input/output saturation to the colour correction module
  * added support for embedding the processing parameters inside the
    (XMP) metadata of the output images
  * added "saturation control" to the dynamic range compression module
  * added new experimental "dynamic row noise" filter
    (under Raw Bayer -> preprocessing) to fix colour banding occurring
    when taking long exposures with some Canon cameras
  * tweaked the default theme (for GTK >= 3.20)
* Tue Jun 30 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.4.1 (no changelog)
* Fri Jun 19 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.4 (no changelog)
* Mon Jun  8 2020 Paolo Stivanin <info@paolostivanin.com>
- Adding -fno-tree-loop-vectorize due to https://github.com/Beep6581/RawTherapee/issues/5749
* Sat May  2 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.3 (no changelog)
* Fri Apr 24 2020 Paolo Stivanin <info@paolostivanin.com>
- Initial release 1.2
- Add add_releaseinfo.patch
- Add fix-cmake.patch
